pub enum Error {
IoError(Error),
Overflow,
}Expand description
An enumeration of the possible errors that can occur when reading a number encoded with LEB128.
Variants
IoError(Error)
There was an underlying IO error.
Overflow
The number being read is larger than can be represented.